=======
Credits
=======

Development Lead
----------------

* Catherine Devlin <catherine.devlin@gmail.com>

Contributors
------------

* Brandon Lorenz: Django model generation
* Mikhail Podgurskiy: Doc fix for Github link

